import { HighlightManager, } from "./HighlightManager.js";
import { makeDomAnchorFromRange, makeDomAnchorFromSelection, getRangesFromDomAnchor, } from "./anchors/index.js";
/** A HighlightManager using an anchor for web pages. */
export class DomAnchorHighlightManager extends HighlightManager {
    constructor(options) {
        super({
            ...options,
            getRangesFromAnchor: (anchor) => getRangesFromDomAnchor(options.container, anchor, options.logger),
        });
    }
    createHighlightFromCurrentSelection(data, handlers) {
        const selection = window.getSelection();
        if (!selection) {
            throw new Error("Cannot create highlight from current selection because there isn't one.");
        }
        return this.createHighlightFromSelection(selection, data, handlers);
    }
    createHighlightFromSelection(selection, data, handlers) {
        if (!selection || selection.isCollapsed) {
            throw new Error("Cannot highlight empty selection.");
        }
        const domAnchor = makeDomAnchorFromSelection(selection);
        return this.createHighlight(domAnchor, data, handlers);
    }
    createHighlightFromRange(range, data, handlers) {
        const domAnchor = makeDomAnchorFromRange(range);
        return this.createHighlight(domAnchor, data, handlers);
    }
}
//# sourceMappingURL=DomAnchorHighlightManager.js.map